@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 
 import json
 
-from transifex.common.utils import generate_key, is_plural
+from transifex.common.utils import generate_key, parse_plurals
 from transifex.native.cache import MemoryCache
 from transifex.native.cds import CDSHandler
 from transifex.native.rendering import (SourceStringErrorPolicy,
@@ -84,27 +84,51 @@ class TxNative(object):
         :return: the rendered string
         :rtype: unicode
         """
+
+        if params is None:
+            params = {}
+
         self._check_initialization()
 
-        # Try to retrieve the translation
-        # A translation is a serialized source_string with ICU format support,
-        # e.g. '{num, plural, one {Ένα τραπέζι} other {{num} τραπέζια}}'
+        translation_template = self.get_translation(source_string,
+                                                    language_code,
+                                                    _context,
+                                                    is_source)
+
+        return self.render_translation(translation_template,
+                                       params,
+                                       source_string,
+                                       language_code,
+                                       escape)
+
+    def get_translation(self, source_string, language_code, _context,
+                        is_source=False):
+        """ Try to retrieve the translation.
+
+            A translation is a serialized source_string with ICU format
+            support, e.g.
+            '{num, plural, one {Ένα τραπέζι} other {{num} τραπέζια}}'
+        """
+
         if is_source:
             translation_template = source_string
         else:
-            key = generate_key(source_string, _context)
+            pluralized, plurals = parse_plurals(source_string)
+            key = generate_key(string=source_string, context=_context)
             translation_template = self._cache.get(key, language_code)
-            if (translation_template is not None and
-                    is_plural(source_string) and
+            if (translation_template is not None and pluralized and
                     translation_template.startswith('{???')):
                 variable_name = source_string[1:source_string.index(',')].\
                     strip()
                 translation_template = ('{' +
                                         variable_name +
                                         translation_template[4:])
+        return translation_template
+
+    def render_translation(self, translation_template, params, source_string,
+                           language_code, escape=False):
+        """ Replace the variables in the ICU translation """
 
-        # Replace the variables in the ICU translation
-        params = params or {}
         try:
             return StringRenderer.render(
                 source_string=source_string,
@@ -112,14 +136,14 @@ class TxNative(object):
                 language_code=language_code,
                 escape=escape,
                 missing_policy=self._missing_policy,
-                **params
+                params=params,
             )
         except Exception:
             return self._error_policy.get(
                 source_string=source_string,
                 translation=translation_template,
                 language_code=language_code,
-                escape=escape, **params
+                escape=escape, params=params,
             )
 
     def fetch_translations(self):
@@ -131,10 +155,10 @@ class TxNative(object):
         """Push the given source strings to the CDS.
 
         :param list strings: a list of SourceString objects
-        :param bool purge: True deletes destination source content not included in
-                           pushed content.
-                           False appends the pushed content to destination source
-                           content.
+        :param bool purge: True deletes destination source content not included
+                           in pushed content.
+                           False appends the pushed content to destination
+                           source content.
         :return: a tuple containing the status code and the content of the
             response
         :rtype: tuple
